const pdfsig = require('pdfsig');

const firmas = new pdfsig('prueba.pdf');

const nroFirmas = firmas.size();
console.log(nroFirmas);

if (firmas.estado(0)) {
    console.log('Firma válida, el documento no ha sido modificado.');
} else {
    console.log('El documento ha sido modificado, la firma ya no es válida.');
}

const certificado = firmas.getFirmas()[0].certificados[0];
console.log(certificado.subject.getField('CN').value);
for (let i = 0; i < certificado.subject.attributes.length; i++) {
  if (certificado.subject.attributes[i].type === '1.3.6.1.1.1.1.0') {
    console.log(certificado.subject.attributes[i].value);
  }
}

const cafile = require('fs').readFileSync('firmadigital_bo.pem');
const ca = require('node-forge').pki.certificateFromPem(cafile);
if (ca.verify(certificado)) {
  console.log('Certificado válido (Emitido por la PKI del Estado Plurinacional de Bolivia).');
} else {
  console.log('Certificado inválido.');
}

if (firmas.fecha(0).getTime() >= certificado.validity.notBefore.getTime() && firmas.fecha(0).getTime() <= certificado.validity.notAfter.getTime()) {
  console.log('La firma del documento fue realizada dentro de la vigencia del certificado.');
} else {
  console.log('La firma del documento fue realizada fuera de la vigencia del certificado (No válido).');
}

require('ocsp').check({
  cert: require('node-forge').pki.certificateToPem(certificado),
  issuer: cafile
}, (err, res) => {
  if (res) {
    if (res.type === 'good') {
      console.log('Certificado no revocado.');
    } else {
      console.log(res.value);
    }
  } else {
    console.log(err.message);
  }
});
